@@ -2,8 +2,10 @@ from .attention_modules import Attention
 from .base_modules import Activation, Conv, Identity, Norm, Up
 from .conv_block import ConvBlock
 from .conv_layer import ConvLayer
+from .metaformer import MetaFormer
 from .misc_modules import ChannelPool
 from .self_attention_modules import SelfAttention, SelfAttentionBlock
+from .token_mixers import TokenMixer, TokenMixerBlock
 from .transformers import Transformer2D, TransformerLayer
 
 __all__ = [
@@ -20,4 +22,7 @@ __all__ = [
     "TransformerLayer",
     "Transformer2D",
     "ChannelPool",
+    "MetaFormer",
+    "TokenMixer",
+    "TokenMixerBlock",
 ]
