@@ -17,7 +17,9 @@ from torch.nn import (
     Tanhshrink,
 )
 
+from .gated_gelu import GEGLU, ApproximateGELU
 from .mish import Mish
+from .star_relu import StarReLU
 from .swish import Swish
 
 ACT_LOOKUP = {
@@ -39,9 +41,11 @@ ACT_LOOKUP = {
     "hardshrink": Hardshrink,
     "tanhshrink": Tanhshrink,
     "hardsigmoid": Hardsigmoid,
+    "star_relu": StarReLU,
+    "geglu": GEGLU,
+    "approximate_geglu": ApproximateGELU,
 }
 
-
 __all__ = [
     "Mish",
     "Swish",
@@ -63,4 +67,6 @@ __all__ = [
     "Hardsigmoid",
     "Activation",
     "ACT_LOOKUP",
+    "GEGLU",
+    "ApproximateGELU",
 ]
