@@ -1,4 +1,4 @@
-from torch.nn import BatchNorm2d, InstanceNorm2d, SyncBatchNorm
+from torch.nn import BatchNorm2d, InstanceNorm2d, LayerNorm, SyncBatchNorm
 
 from .bcn import BCNorm
 from .gn import GroupNorm
@@ -6,7 +6,8 @@ from .ln import LayerNorm2d
 
 NORM_LOOKUP = {
     "bn": BatchNorm2d,
-    "ln": LayerNorm2d,
+    "ln2d": LayerNorm2d,
+    "ln": LayerNorm,
     "bcn": BCNorm,
     "gn": GroupNorm,
     "in": InstanceNorm2d,
@@ -20,4 +21,5 @@ __all__ = [
     "InstanceNorm2d",
     "SyncBatchNorm",
     "LayerNorm2d",
+    "LayerNorm",
 ]
